@@ -1,5 +1,5 @@
 ;;;; prime-fund-mode.el: Fundamental submode of PRIME mode.
-;;;; $Id: prime-fund-mode.el,v 1.3 2004/03/19 17:56:09 komatsu Exp $
+;;;; $Id: prime-fund-mode.el,v 1.4 2004/12/06 08:39:38 komatsu Exp $
 ;;;;
 ;;;; Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ;;;;     All rights reserved.
@@ -49,27 +49,12 @@
     (call-interactively (mell-key-binding-next prime-fund-mode-map))
     ))
 
-;(defun prime-fund-convert-region ()
-;  (interactive)
-;  (if (mell-transient-region-active-p)
-;      (let ((pattern (suikyo-convert-kana-romaji
-;		      (buffer-substring (region-beginning) (region-end)))))
-;	(if (string-match "\\cj" pattern)
-;	    (message (concat "$B:FJQ49$KBP1~$7$F$$$J$$J8;zNs$,4^$^$l$F$$$^$9(B. ("
-;			     pattern ")"))
-;	  (setq prime-pat pattern)
-;	  (delete-region (region-beginning) (region-end))
-;	  (prime-input-mode-on t)
-;	  (prime-disp-input)))
-;    (call-interactively (mell-key-binding-next prime-fund-mode-map))
-;    ))
-
 (defun prime-fund-undo ()
   (interactive)
   (undo)
   (if (member last-command '(prime-conv-decide prime-keyin))
       (progn
-	(setq prime-pat      prime-pat-for-undo)
+	(prime-input-undo)
 	(if prime-conv-mode-for-undo
 	    (progn
 	      (prime-conv-mode-on)
