@@ -356,7 +356,7 @@
       ;; marker $B$O(B (] $B$G$"$k(B.
       (insert " ")
       (mell-marker-set 'prime-cand-list-begin (point))
-      (prime-disp-cand-list-one)
+      (prime-disp-cand-list-compact)
       )
      ((or prime-cand-mode
 	  (and prime-conv-mode (eq prime-style-display-candidates 'all)))
