@@ -1,5 +1,5 @@
 ;;;; prime.el: Emacs Lisp for PRIME
-;;;; $Id: prime.el,v 1.6 2004/12/07 12:29:04 komatsu Exp $
+;;;; $Id: prime.el,v 1.7 2005/02/15 23:09:51 komatsu Exp $
 ;;;;
 ;;;; Copyright (C) 2002, 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ;;;;     All rights reserved.
@@ -161,9 +161,11 @@ PRIME is a Japanese Predictive Input Method Editor."
 (defun prime-convert-region (beg end)
   (interactive "r")
   (let ((pattern (japanese-hiragana (buffer-substring beg end))))
-    (if nil   ;; (string-match "\\cj" pattern)
-	(message (concat "ѴбƤʤʸ󤬴ޤޤƤޤ. "
-			 "(" pattern ")"))
+;;     (if nil   ;; (string-match "\\cj" pattern)
+;; 	(message (concat "ѴбƤʤʸ󤬴ޤޤƤޤ. "
+;; 			 "(" pattern ")"))
+    (if (string-match "\n" pattern)
+	(message "ѴˤϲԤޤʤǤ")
       (setq prime-start-pat (buffer-substring beg end))
       (prime-input-mode-on t)
       (delete-region beg end)
